<?php

/**
 * @file
 * Custom Drush integration.
 */

/**
 * Implements hook_drush_command().
 *
 * @return array
 *   An associative array describing your command(s).
 */
function devit_drush_command() {
  return array(
    'devit' => array(
      'callback' => 'devit_drush',
      'description' => dt('Puts your site in dev mode.'),
    ),
  );
}

/**
 * Put the site in Dev It.
 */
function devit_drush() {
  devit_devit();
  drush_log('Site ready for development!', 'success');
}

/**
 * Prompt user to set new values for variables.
 *
 * This allows the user to enter a new value manually, or accept the default,
 * new value provided by the calling function. Optional messages may be
 * displayed for the prompting question and confirmation messages.
 *
 * @param array $variables
 *   An associative array containing variables to be set.
 *   - name: variable name
 *   - default value: default, new value for variable.
 *   - (optional) prompt: Untranslated prompt message. @name token is available.
 *   - (optional) accepted message: Untranslated response for when user
 *     accepts default, new value. @name and @new_value tokens available.
 *   - (optional) overridden message: Untranslated response for when user
 *     overrides default, new variable value with a custom value. @name and
 *     @new_value tokens available.
 */
function devit_drush_variable_set_prompt($variables) {
  foreach ($variables as $name => $variable) {
    $default = variable_get($name);

    // A prompt has been specified.
    if (!empty($variable['prompt'])) {
      $prompt = dt($variable['prompt'], array('@name' => $name));
    }
    // No default prompt was specified.
    elseif (!isset($variable['prompt'])) {
      $prompt = dt("Update variable @name?", array('@name' => $name));
    }
    // Prompt was set to FALSE. Set the variable now.
    else {
      variable_set($name, $variable['default value']);
      $new_value = $variable['default value'];
      $args = array('@name' => $name, '@new_value' => $new_value);
      $response = !empty($variable['overridden message']) ? dt($variable['overridden message'], $args) : dt('Variable @name set to @new_value', $args);
      drush_log($response, 'success');
    }

    // Prompt the user before setting the variable.
    if (!empty($prompt)) {
      $entry  = drush_prompt($prompt, $variable['default value']);
      if ($default != $entry) {
        variable_set($name, $entry);
        $args = array('@name' => $name, '@new_value' => $entry);
        $response = !empty($variable['overridden message']) ? dt($variable['overridden message'], $args) : dt('Variable @name set to @new_value', $args);
      }
      else {
        $args = array('@name' => $name, '@new_value' => $default);
        $response = !empty($variable['accepted message']) ? dt($variable['accepted message'], $args) : dt('Variable @name will remain @new_value', $args);
      }
      drush_log($response, 'success');
    }
  }
}

/**
 * Enables an array of modules and displays message to user.
 */
function devit_drush_enable_modules($modules) {
  module_enable($modules, TRUE);
  foreach ($modules as $module) {
    if (module_exists($module)) {
      drush_log(dt('@module enabled.', array('@module' => $module), 'success'));
    }
    else {
      drush_log(dt('@module could not be found and was not enabled!', array('@module' => $module), 'error'));
    }
  }
}
